@@ -47,14 +47,13 @@
  */
 $SPAF_VERSION = '2.1.2';
 
-$MODULE = ereg_replace('\.php$','', basename($_SERVER['SCRIPT_NAME']));
+$MODULE = preg_replace('/\.php$/','', basename($_SERVER['SCRIPT_NAME']));
 if (! file_exists($MODULE)) {
     $MODULE = '.';
 }
 else {
     ini_set('include_path',ini_get('include_path').':./'.$MODULE);
 }
-ini_set('include_path',ini_get('include_path').':./lib');
 
 /**
  * Allow php to load classes at first.
@@ -70,8 +69,20 @@ if ((! isset($SP_CONFIG)) && (! isset($configfile))) {
     exit();
 }
 
+// set cookie path
+$currentCookieParams = session_get_cookie_params();
+session_set_cookie_params(
+    $currentCookieParams["lifetime"],
+    $_SERVER['SCRIPT_NAME'],
+    $currentCookieParams["domain"],
+    $currentCookieParams["secure"],
+    $currentCookieParams["httponly"]
+);
 session_start();
 
+// suppress notice messages 
+error_reporting(error_reporting()&~E_NOTICE);
+
 /**
  * Application framework object
  *
@@ -116,7 +127,7 @@ else {
     $CURRENT_ACTION = $App->getParam('CA');
 }
 
-if (! $CURRENT_ACTION || ! ereg('^[a-zA-Z0-9_-]+$',$CURRENT_ACTION)) {
+if (! $CURRENT_ACTION || ! preg_match('/^[a-zA-Z0-9_-]+$/',$CURRENT_ACTION)) {
     $CURRENT_ACTION = 'default';
 }
 
@@ -147,18 +158,6 @@ if (file_exists($SP_FILE)) {
         $App->view = 'default';
     }
 }
-elseif (file_exists($SP_FILE='./lib/ctrl/'.$CURRENT_ACTION.'.php')) {
-    if ($App->authz($CURRENT_ACTION)) {
-        if ($DEBUG) error_log("[SPAF2]:CALL $SP_FILE");
-        include $SP_FILE;
-    }
-    else {
-        // authzError
-        if ($DEBUG) error_log("[SPAF2]:ERR_AUTHZ $SP_FILE");
-        $App->view = 'default';
-    }
-}
-
 
 /* *** POST CTRL HOOK ***/
 if (file_exists($MODULE.'/post_ctrl.php')) {
@@ -176,7 +175,6 @@ if ($DEBUG) error_log("[SPAF2]:VIEW ".$App->view);
 // check if file exists or call default view file. The default view
 // will not checked for authorization.
 $SP_FILE = $MODULE.'/view/' . $App->view . '.php';
-// check if module file underneath the lib structure exists
 if (file_exists($SP_FILE)) {
     if ($App->authz($App->view)) {
         if ($DEBUG) error_log("[SPAF2]:CALL $SP_FILE");
@@ -188,17 +186,6 @@ if (file_exists($SP_FILE)) {
         $App->view = 'default';
     }
 }
-elseif (file_exists($SP_FILE='./lib/view/'.$CURRENT_ACTION.'.php')) {
-    if ($App->authz($CURRENT_ACTION)) {
-        if ($DEBUG) error_log("[SPAF2]:CALL $SP_FILE");
-        include $SP_FILE;
-    }
-    else {
-        // authzError
-        if ($DEBUG) error_log("[SPAF2]:ERR_AUTHZ $SP_FILE");
-        $App->view = 'default';
-    }
-}
 
 /* *** POST VIEW HOOK ***/
 if (file_exists($MODULE.'/post_view.php')) {
