@@ -44,13 +44,11 @@
  *   APP_AUTHZLEVEL
  *
  */
-// dirty hack to run silently on all systems
-@include_once 'smarty/libs/Smarty.class.php';    // Debian
-@include_once 'smarty/Smarty.class.php';         // Ubuntu
-@include_once 'Smarty/Smarty.class.php';         // RHEL / CentOS
+@include_once 'lib/Smarty.class.php';
 
 require_once 'SPAF2/ApplicationConfig.php';
 require_once 'SPAF2/DBAccess.php';
+require_once 'SPAF2/AppUtils.php';
 
 class Application extends ApplicationConfig
 {
@@ -182,6 +180,36 @@ class Application extends ApplicationConfig
     var $TPL;
 
 
+    /**
+     * skin
+     *
+     * Holds the name of the skin subdir
+     *
+     * @access public
+     */
+    var $skin;
+
+
+    /**
+     * lang
+     *
+     * Holds the name of the language setting
+     *
+     * @access public
+     */
+    var $lang;
+
+
+    /**
+     * date_format
+     *
+     * Holds the current date format 
+     *
+     * @access public
+     */
+    var $date_format;
+
+
     /**
      * template
      *
@@ -192,6 +220,16 @@ class Application extends ApplicationConfig
     var $template;
 
 
+    /**
+     * message_file
+     *
+     * Filename of the message file
+     *
+     * @access public
+     */
+    var $message_file;
+
+
     /**
      * view
      *
@@ -239,10 +277,44 @@ class Application extends ApplicationConfig
 
         $this->module   = $MODULE;
         $this->_request = & $_REQUEST;
-        $this->Error    = new ApplicationError ($this->configdir.'/'.$this->config['ERRORMSG']);
-
         $this->_session = & $_SESSION;
+        $this->DEBUG = $this->getConfig('DEBUG');
 
+        // Language settings
+        $default_locale = $this->getConfig('DEFAULT_LANGUAGE');
+        if ($this->getParam('LANG')) {
+            $this->lang = $this->getParam('LANG');
+        }
+        elseif ($this->getSession('LANG')) {
+            $this->lang = $this->getSession('LANG');
+        }
+        else {
+            $this->lang = AppUtils::GetLocaleFromBrowser($default_locale, false);
+        }
+        $this->setSession('LANG',$this->lang);
+
+        // date format
+        switch ($this->lang) {
+            case 'de':
+                $this->date_format = '%d.%m.%Y';
+                break;
+            case 'en':
+                $this->date_format = '%m/%d/%Y';
+                break;
+        }
+
+
+        if ($this->getParam('SKIN')) {
+            $this->skin = $this->getParam('SKIN');
+        }
+        elseif ($this->getSession('SKIN')) {
+            $this->skin = $this->getSession('SKIN');
+        }
+        else {
+            $this->skin = $this->lang;
+        }
+
+        // Template initialization
         $this->TPL = new Smarty;
         $this->TPL->compile_check = true;
 
@@ -252,13 +324,36 @@ class Application extends ApplicationConfig
         else {
             $root_dir = getcwd();
         }
-        $this->TPL->template_dir = $root_dir.'/'.$this->module.'/templates';
 
-        $templates_cache = $this->getConfig('TEMPLATE_CACHE');
-        if (is_writable($templates_cache)) {
-            $this->TPL->compile_dir = $templates_cache;
+        $skin_dir = $root_dir.'/'.$this->module.'/templates/'.$this->skin;
+        if (! is_dir($skin_dir)) {
+            $skin_dir = $root_dir.'/'.$this->module.'/templates/'.$default_locale;
+        }
+        $this->TPL->template_dir = $skin_dir;
+
+        $message_file = $skin_dir.'.msg';
+        if (! is_readable($message_file)) {
+            $message_file = $skin_dir.'/'.$default_locale.'.msg';
+        }
+
+        // messages from file
+        $this->message_file = $message_file;
+        $this->Error = new ApplicationError ($message_file);
+
+
+        if ($this->DEBUG) {
+            $this->log('[SPAF2/Application]:template_dir '.$skin_dir);
+        }
+        $templates_cache_base = $this->getConfig('TEMPLATE_CACHE');
+        $templates_cache_skin = $templates_cache_base.'/'.$this->skin;
+        if (!is_dir($templates_cache_skin)) {
+            mkdir($templates_cache_skin);
+        }
+        if (is_writable($templates_cache_skin)) {
+            $this->TPL->compile_dir = $templates_cache_skin;
         }
         else {
+            $this->log('WARNING: Cannot write to templates cache: '.$templates_cache_skin);
             $this->TPL->compile_dir = '/tmp';
         }
         $this->TPL->config_dir   = $this->configdir;
@@ -271,7 +366,6 @@ class Application extends ApplicationConfig
         if ($DEBUG = $this->getParam('DEBUG')) {
             $this->setSession('DEBUG',$DEBUG);
         }
-        $this->DEBUG = $this->getConfig('DEBUG');
         $this->TPL->assign('DEBUG',$this->DEBUG);
 
         if (isset($this->config['DBTYPE'])) {
@@ -279,6 +373,8 @@ class Application extends ApplicationConfig
                                      $this->config['DBPASS'],$this->config['DBHOST'],
                                      $this->config['DATABASE']);
         }
+
+
     }
 
 
@@ -398,7 +494,6 @@ class Application extends ApplicationConfig
      */
     function compile ($template)
     {
-
         /* The smarty debuggig could only be used with the display
          * method.
          */
@@ -408,7 +503,7 @@ class Application extends ApplicationConfig
             $this->TPL->display($template);
             $this->_output .= ob_get_contents();
         }
-        elseif($this->config['DEBUG'] > 0) {
+        elseif(@$this->config['DEBUG'] > 0) {
             $this->log("[SPAF2/Application] NO TEMPLATE $template");
         }
         ob_end_clean();
@@ -623,11 +718,21 @@ class Application extends ApplicationConfig
         }
         elseif (isset($_SERVER['HTTPS'])) {
             $PROTO = 'https://';
-            $location = 'Location: '.$PROTO.$_SERVER['HTTP_HOST'].$_SERVER['SCRIPT_NAME']."?$params";
+            $http_host = $_SERVER['HTTP_HOST'];
+            if (!preg_match('/^[a-z\d:\.](-*[a-z\d:\.])*$/',$http_host)) {
+                $this->log('Exit while invalid hostname for redirect: '.$http_host);
+                exit;
+            }
+            $location = 'Location: '.$PROTO.$http_host.$_SERVER['SCRIPT_NAME']."?$params";
         }    
         else {            
             $PROTO = 'http://';
-            $location = 'Location: '.$PROTO.$_SERVER['HTTP_HOST'].$_SERVER['SCRIPT_NAME']."?$params";
+            $http_host = $_SERVER['HTTP_HOST'];
+            if (!preg_match('/^[a-z\d:\.](-*[a-z\d:\.])*$/',$http_host)) {
+                $this->log('Exit while invalid hostname given for redirect: '.$http_host);
+                exit;
+            }
+            $location = 'Location: '.$PROTO.$http_host.$_SERVER['SCRIPT_NAME']."?$params";
         } 
 
         header($location);
@@ -704,16 +809,29 @@ class Application extends ApplicationConfig
      * Fetches the message from the file $confdir/ERRORMSG
      *
      * @access public
-     * @param string $msg symbol
+     * @param string $msg_sym symbol
      * @return $bool TRUE
      */
-    function setMsg ($msg='')
+    function setMsg ($msg_sym='')
     {
-        if ($msg) {
-            $Msg = new ApplicationConfig($this->configdir);
-            $Msg->load($this->getConfig('ERRORMSG'));
-            $this->assign('MSG',$Msg->getConfig($msg));
-        } 
+        $msg_string = '';
+        if (! $fd = @fopen ($this->message_file, "r")) {
+	        $this->log('ERROR: Cannot read message file '.$this->message_file);
+        }
+        else {
+            while (!feof ($fd)) {
+                $buffer = fgets($fd, 255);
+                if (preg_match("/^#/",$buffer)) continue;
+                if (preg_match("/^\s*$/",$buffer)) continue;
+                list($param,$value) = preg_split ("/\s*=\s*/",$buffer,2);
+                if ($param == $msg_sym) {
+                    $msg_string = rtrim($value);
+                    break;
+                }
+            }
+            fclose($fd);
+        }
+        $this->assign('MSG',$msg_string);
         return TRUE;
     }
  
