@@ -210,41 +210,30 @@ class Persistence
      * The method returns TRUE or FALSE if the database transaction failed.
      *
      * @access public
-     * @param array $attributes (optional)
      * @return TRUE | FALSE
      */
-    function save ($attributes='')
+    function save ()
     {
         global $App;
         $DB = $App->DB;
 
         $tablename = $this->_tablename();
-        if ($attributes) {
-            $primary_key = $attributes[0]; // first attribute is key
-            $primary_val = $this->$primary_key;
-            foreach ($attributes as $attr) {
-                $attrs[$attr] = $this->$attr;
-            }
-        }
-        else {
-            $attrs = $this->_getAttributeList();
-            if (! array_key_exists('id',$attrs)) {
-                error_log("[SPAF2/Persistence] Attribute 'id' does not exist at class \'$tablename\'.");
-                throw new Exception('No id in object');
-            }
-
-            $primary_key = 'id'; // first attribute is key
-            $primary_val = $this->id;
-            // construct id if not set
-            if (! $this->id)
-                $this->id = uniqid(getmypid()); 
+        $attrs = $this->_getAttributeList();
+        if (! array_key_exists('id',$attrs)) {
+            error_log("[SPAF2/Persistence] Attribute 'id' does not exist at class \'$tablename\'.");
+            throw new Exception('No id in object');
         }
 
+        $primary_key = 'id'; // first attribute is key
+        $primary_val = $this->id;
+        // construct id if not set
+        if (! $this->id)
+            $this->id = uniqid(getmypid()); 
 
         // construct update query
         $sql_update = "UPDATE $tablename SET ";
         foreach ($attrs as $var => $val) {
-            $sql_update .= $DB->quote($var)."='".$val."',";
+            $sql_update .= $var."='".$val."',";
         }
         // remove the last comma
         $sql_update = rtrim($sql_update,',');
@@ -262,9 +251,17 @@ class Persistence
         $sql_insert = rtrim($sql_insert,',');
         $sql_insert .= ');';
 
+        // check if row exist
+        $sql_select = 'SELECT count(*) FROM '.$tablename.
+                      ' WHERE '.$primary_key." = '".$primary_val."';";
+        $DBResult = $DB->query($sql_select);
+        $row = $DBResult->fetchRow();
+
         $DB->startTransaction();
-        $row = $DB->query($sql_update);
-        if ($DB->affectedRows() === 0) {
+        if ($row['count(*)'] >= 1) {
+            $DBResult = $DB->query($sql_update);
+        }
+        else {
             $DB->query($sql_insert);
         }
 
@@ -296,7 +293,7 @@ class Persistence
         }
 
         $tablename = $this->_tablename();
-        $sql_delete = 'DELETE FROM '.$DB->quote($tablename).' WHERE '.$primary_key." = '$primary_val'";
+        $sql_delete = 'DELETE FROM '.$tablename.' WHERE '.$primary_key." = '$primary_val'";
         $row = $DB->query($sql_delete);
         return $DB->affectedRows();
     }
