@@ -71,7 +71,7 @@ catch (Exception $e) {
 // LOGIN SUCCESSFUL
 
 // initialize backend
-$archive = $User->getArchive();
+$archive = end($User->getArchives());
 $FilterList = Filter::FetchList($User);
 $filterString = '';
 foreach ($FilterList as $Filter) {
@@ -79,7 +79,6 @@ foreach ($FilterList as $Filter) {
 }
 $Backend = new Backend($base_url,$archive,$filterString);
 
-
 // initialize session
 $App->setSession('ACCESS_LEVEL',$User->getAuthzLevel());
 $App->setSession('USER',$User);
@@ -106,6 +105,10 @@ catch (Exception $e) {
     $App->log('Error loading application state: '.$e->getMessage());
 }
 
+// Store skin in session
+if ($App->getSession('language')) {
+    $App->setSession('SKIN',$App->getParam('language'));
+}
 
 // redirect user to search mask
 $App->redirect('greeting');
