@@ -40,10 +40,15 @@ try {
 catch (Exception $e) {
     $App->log('[logoff] '.$e->getMessage());
 }
+$messages = array(
+    'MSG'       => 'MSG_LOGOUT',
+    'SKIN'      => $App->getSession('SKIN'),
+    'language'  => $App->getSession('LANG')
+);
+
 $App->setSession('User','');
 $App->setSession('ACCESS_LEVEL',0);
 session_destroy();
 
-
-$App->redirect('default',array('MSG'=>'MSG_LOGOUT'));
+$App->redirect('default',$messages);
 ?>
