@@ -34,7 +34,7 @@
 $sessionMailId = $App->getParam('id');
 
 try {
-    $RawMail = $Backend->fetchRaw($sessionMailId);
+    $RawMail = $Backend->fetchRaw($sessionMailId,true);
     $App->view = 'showRawMail';
 }
 catch (Exception $e) {
