@@ -41,8 +41,8 @@ $queryId = uniqid($User->id);
 
 $ExtQuery = new Query($queryId,
         $extForm['text'],
-        DateConvert::Date2Timestamp($extForm['dateFrom']),
-        DateConvert::Date2Timestamp($extForm['dateTo']),
+        DateConvert::Date2Timestamp($extForm['dateFrom'],$App->date_format),
+        DateConvert::Date2Timestamp($extForm['dateTo'],$App->date_format),
         $extForm['sender'],
         $extForm['recipient'],
         $extForm['subject'],
