@@ -122,7 +122,7 @@ class Backend
      * @param string $sessionMailId
      * @return string $maildata
      */
-    function fetchRaw ($sessionMailId)
+    function fetchRaw ($sessionMailId,$recodeToUTF8=false)
     {
         $bennoId = QueryResult::getBennoId($sessionMailId);
 
@@ -131,6 +131,9 @@ class Backend
 //                        '&filterQuery='.$this->filter.
                         '&id='.$bennoId.
                         '&format=raw';
+        if (!$recodeToUTF8) {
+            $query_string .= '&skipUTF8Recode=true';
+        }
 
         $maildata = $this->_curl_query($request_url,$query_string,'raw');
         $result = json_decode($maildata, true);
