@@ -171,15 +171,26 @@ class EMail
         $body['text/plain'] = '';
         $body['text/html'] = '';
         $body['unknown'] = '';
+        $count['text/plain'] = 0;
+        $count['text/html'] = 0;
         if (isset($this->body)) {
             foreach ($this->body as $bodypart) {
                 $partContentType = $bodypart['content-type'];
                 if (stripos($partContentType,'text/html') !== false) {
-                    $body['text/html'] .= $bodypart['data'];
+                    $body['text/html'] .= $bodypart['data']."\n";
+                    if ($count['text/html'] == 1) {
+                        $Attachment = new Attachment('content.disclaimer',$partContentType,0,false);
+                        $this->addAttachment($Attachment);
+                    }
                     continue;
                 }
                 if (stripos($partContentType,'text/plain') !== false) {
-                    $body['text/plain'] .= $bodypart['data'];
+                    $body['text/plain'] .= $bodypart['data']."\n";
+                    if ($count['text/plain'] == 1) {    // disclaimer part
+                        $Attachment = new Attachment('content.disclaimer',$partContentType,0,false);
+                        $this->addAttachment($Attachment);
+                    }
+                    $count['text/plain']++;
                     continue;
                 }
                 $body['unknown'] = $bodypart['data'];
