@@ -157,23 +157,7 @@ class Filter extends Persistence
 
         $filter = '';
         foreach($filter_attributes as $attribute) {
-            $filter .=  $attribute.':'.'*%3C'.$address.'%3E'.
-                        ' '.
-                        $attribute.':'.'*%3C'.$address_lowered.'%3E'.
-                        ' '.
-                        $attribute.':'.'*'.$address.
-                        ' '.
-                        $attribute.':'.'*'.$address_lowered.
-                        ' '.
-                        $attribute.':'.'*,'.$address.
-                        ' '.
-                        $attribute.':'.'*,'.$address_lowered.
-                        ' '.
-                        $attribute.':'.'*'.$address.','.
-                        ' '.
-                        $attribute.':'.'*'.$address_lowered.','.
-                        ' '
-                        ;
+            $filter .=  $attribute.':'.$address.' ';
         }
         return '('.$filter.')';
     }
