@@ -83,29 +83,29 @@ class Query
 
 
     /**
-     * returns date as DD.MM.YYYY
+     * returns formatted date
      *
      * @return string
-     *
      */
     function getDateFrom()
     {
+        global $App;
         if ($this->dateFrom) {
-            return strftime('%d.%m.%Y',$this->dateFrom);
+            return strftime($App->date_format,$this->dateFrom);
         }
     }
 
 
     /**
-     * returns date as DD.MM.YYYY
+     * returns formatted date
      *
      * @return string
-     *
      */
     function getDateTo()
     {
+        global $App;
         if ($this->dateTo) {
-            return strftime('%d.%m.%Y',$this->dateTo);
+            return strftime($App->date_format,$this->dateTo);
         }
     }
 
@@ -130,7 +130,7 @@ class Query
         }
 
         if ($App->DEBUG >= 1) {
-            $App->log('query_string: '.$query_string);
+            $App->log('[Query] '.$query_string);
         }
         return $query_string;
     }
@@ -234,7 +234,7 @@ class Query
         $query_string = '('.$this->_format_query($qstring,$fieldlist).')';
 
         if (! $this->isSpam) {
-            $query_string .= ' AND (NOT HEADER-X-SPAM-FLAG:YES)';
+            $query_string .= ' AND NOT HEADER-X-SPAM-FLAG:YES';
         }
 
         $date_range   = $this->_dateRange($this->dateFrom,$this->dateTo);
@@ -252,13 +252,18 @@ class Query
      */
     function _extendedQuery ()
     {
+        global $App;
+
         $and   = ' AND ';
         $or    = ' OR ';
 
         $query_string = '';
 
         if ($this->sender !== '') {
-            $sender_q = '*'.$this->sender.'*';
+            $sender_q = $this->sender.'*';
+            if (!$App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
+                $sender_q = '*'.$this->sender.'*';
+            }
             $sender_string = $this->_format_query($sender_q,'Sender');
             // (!)Sender contains plain email adress without names
             $from_string   = $this->_format_query($sender_q,'From');
@@ -267,7 +272,10 @@ class Query
         }
 
         if ($this->recipient !== '') {
-            $recipient_q = '*'.$this->recipient.'*';
+            $recipient_q = $this->recipient.'*';
+            if (!$App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
+                $recipient_q = '*'.$this->recipient.'*';
+            }
             // (!)Recipient contains plain email adress without names
             $recipient_string = $this->_format_query($recipient_q,'Recipient');
             $to_string        = $this->_format_query($recipient_q,'To');
@@ -327,6 +335,8 @@ class Query
     */
     function _format_query($qstring,$field)
     {
+        global $App;
+
         if (is_array($field)) {
             $fieldlist = $field;
         }
@@ -340,6 +350,13 @@ class Query
             $query_string .= '('.$field_string.')';
         }
 
+        if ($App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
+            if (preg_match('/:[\*\?]/',$query_string)) {
+                $App->log('[Query] Remove leading wildcards from query.');
+                throw new Exception('LEADING_WILDCARD');
+            }
+        }
+
         return $query_string;
     }
 
