@@ -81,7 +81,7 @@ class UserDA extends Persistence
         $row = $res->fetchRow();
         $this->password = $row['password'];
         $this->name = $row['name'];
-        $this->archive = $row['archive'];
+        array_push($this->archive,$row['archive']);
         $this->role = $row['role'];
 
         // read address data
@@ -95,10 +95,18 @@ class UserDA extends Persistence
     }
 
 
-    // load userdata from external userdb via script
+    // load userdata from external userdb via script parameters
     function loadExternal ($script,$loadpass=false)
     {
 
+        try {
+            return $this->loadSExternal($script,$loadpass);
+        }
+        catch (Exception $e) {
+            // external auth via STDIN failed
+            error_log('External auth with STDIN protocol failed.');
+        }
+
         if (!is_executable($script)) {
             error_log('Authentication script '.$script.' is not executable.');
             throw new Exception('ERR_INTERN');
@@ -126,6 +134,71 @@ class UserDA extends Persistence
         $username = escapeshellcmd($this->id);
         $retvalue = shell_exec("$cmd \"$username\" \"$password\"");
 
+        return $this->_check_external_return($retvalue);
+    }
+
+
+    // load userdata from external userdb via script stdin/out
+    function loadSExternal ($script,$loadpass=false)
+    {
+        if (!is_executable($script)) {
+            error_log('Authentication script '.$script.' is not executable.');
+            throw new Exception('ERR_INTERN');
+        }
+
+        if ($loadpass === false) {
+            $password = $this->password;
+        }
+        else {
+            $password = ($loadpass);
+        }
+        $username = $this->id;
+
+        $fd = array(
+            0 => array('pipe', 'r'),
+            1 => array('pipe', 'w'),
+            2 => array('pipe', 'w')
+        );
+
+        $cmd = escapeshellcmd($script);
+        $process = proc_open($cmd, $fd, $pipes);
+
+        if (is_resource($process)) {
+            // write "<username> <password>"
+            fwrite($pipes[0], $username.' '.$password);
+            fclose($pipes[0]);
+
+            // read stdout from script
+            $retvalue = stream_get_contents($pipes[1]);
+            fclose($pipes[1]);
+
+            $errvalue = stream_get_contents($pipes[2]);
+            fclose($pipes[2]);
+
+            $return_value = proc_close($process);
+        }
+        // Returnvalues:
+        //  ERROR ERR_AUTH | ERR_INTERN | (symbol in benno-errors.txt)
+        //  ROLE USER | REVISOR | ADMIN
+        //  DISPLAYNAME Martin Werthmöller
+        //  ARCHIVE LWsystems
+        //  MAIL mw@lw-systems.de
+        //  MAIL m.werthmoeller@lw-systems.de
+        //  MAIL info@lw-systems.de
+        return $this->_check_external_return($retvalue);
+    }
+
+
+    // Overwrites Persistence::save()
+    function save ()
+    {
+        error_log("[User::save] not yet implemented\n");
+        return FALSE;
+    }
+
+
+    // private
+    function _check_external_return($retvalue) {
         $retlines = preg_split('/\n/',$retvalue);
         foreach ($retlines as $line) {
             $line = trim($line);
@@ -142,7 +215,7 @@ class UserDA extends Persistence
                     $this->name = $data;
                     break;
                 case 'ARCHIVE':
-                    $this->archive = $data;
+                    array_push($this->archive,$data);
                     break;
                 case 'MAIL':
                     array_push($this->addresses,$data);
@@ -155,13 +228,5 @@ class UserDA extends Persistence
         return FALSE;
     }
 
-
-   // Overwrites Persistence::save()
-    function save ()
-    {
-        error_log("[User::save] not yet implemented\n");
-        return FALSE;
-    }
-
 }
 ?>
