@@ -79,4 +79,8 @@ $timeslice = $App->getSession('timeslice');
 // sort messages (dateAsc dateDesc)
 $sortOrder = $App->getSession('sortOrder');
 
+// refresh last request time (session timeout)
+$lastRequestTime = $App->getSession('lastRequestTime'); // view/a_sessionRefresh
+$App->setSession('lastRequestTime',time());
+
 ?>
